aboutsummaryrefslogtreecommitdiff
path: root/build/dump.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2015-03-31 06:36:46 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2015-03-31 06:36:46 +0200
commit276a0796a97b0a312c0071bba0bf924b5f5c6eee (patch)
treeca876a7af9a63250b85efb973acc72b30c67143a /build/dump.cxx
parent618c44ec5e85f7d07540234a0de9fac6e2913243 (diff)
Rename root_scope to global_scope
To avoid confusion with project's root scopes.
Diffstat (limited to 'build/dump.cxx')
-rw-r--r--build/dump.cxx20
1 files changed, 10 insertions, 10 deletions
diff --git a/build/dump.cxx b/build/dump.cxx
index 45ec584..0287d4a 100644
--- a/build/dump.cxx
+++ b/build/dump.cxx
@@ -104,16 +104,16 @@ namespace build
if (ts == &p)
{
// If this is the ultimate root scope, check that this target
// hasn't been handled by the src logic below.
//
- f = (ts != root_scope || rts.find (&t) == rts.end ());
+ f = (ts != global_scope || rts.find (&t) == rts.end ());
}
// If this target is in the ultimate root scope and we have a
// corresponding src directory (i.e., we are a scope inside a
// project), check whether this target is in our src.
//
- else if (ts == root_scope && p.src_path_ != nullptr)
+ else if (ts == global_scope && p.src_path_ != nullptr)
{
if (t.dir.sub (p.src_path ()))
{
@@ -151,9 +151,9 @@ namespace build
string ind;
set<const target*> rts;
auto i (scopes.begin ());
- scope& r (i->second); // Root scope.
- assert (&r == root_scope);
- dump_scope (r, ++i, ind, rts);
+ scope& g (i->second); // Global scope.
+ assert (&g == global_scope);
+ dump_scope (g, ++i, ind, rts);
cerr << endl;
}
}
@@ -104,16 +104,16 @@ namespace build
if (ts == &p)
{
- // If this is the ultimate root scope, check that this target
- // hasn't been handled by the src logic below.
+ // If this is the global scope, check that this target hasn't
+ // been handled by the src logic below.
//
@@ -104,16 +104,16 @@ namespace build
}
- // If this target is in the ultimate root scope and we have a
- // corresponding src directory (i.e., we are a scope inside a
- // project), check whether this target is in our src.
+ // If this target is in the global scope and we have a corresponding
+ // src directory (i.e., we are a scope inside a project), check
+ // whether this target is in our src.
//